@@ -37,10 +37,15 @@ class CEnemy
   QPixmap *getWinImage();
   QPixmap *getNormalImage();
   QPixmap *getImage();
+  void setResult(unsigned int win, unsigned int lost );
+  void getResult(unsigned int* win, unsigned int* lost );
+  void win();
+  void lost();
 
  private:
   int m_strong;     /*  ɤ߿          */
   QPixmap *m_Img[CENEMY_IMGCNT];
+  unsigned int m_result[2]; //0:win 1:lost
   
 };
 
