@@ -25,6 +25,7 @@
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qkeycode.h>
+#include <qdir.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -38,6 +39,12 @@
 #include "status.h"
 #include "config.h"
 
+// achievement files
+#define ACHIEVEMENT_DIR    ".qmatrix"
+#define ACHIEVEMENT_FNAME  ".qmatrix/result.dat"
+
+#define COPYLIGHT_STR "(C)2000-2005 TAIGA YONEKURA ALL RIGHTS RESERVED"
+
 CGameWidget::CGameWidget(QWidget *parent, const char *name, WFlags f) :
     QWidget(parent, name, f)
 {
@@ -48,6 +55,17 @@ CGameWidget::CGameWidget(QWidget *parent, const char *name, WFlags f) :
 
     m_thinking = 0;
 
+    // setup score directory
+    QDir dir;
+    if( !dir.exists( ACHIEVEMENT_DIR ) ){
+      dir.mkdir( ACHIEVEMENT_DIR );
+    }
+    m_pAchieve = new CAchievement(ACHIEVEMENT_FNAME);
+    if( !m_pAchieve->DownLoad() ){
+      // fail download
+      m_pAchieve->SaveReslut();// make file
+    }
+
     CImageLoader imgloader;
 
     m_timer = new QTimer(this);
@@ -56,6 +74,7 @@ CGameWidget::CGameWidget(QWidget *parent, const char *name, WFlags f) :
     m_pixmap = 0;
 
     /* load image datas */
+    imgloader.LoadImage(&m_bootlogoImg,BOOTLOGO_IMG);
     imgloader.LoadImage(&m_titleImg[0],TITLE_IMG);
     imgloader.LoadImage(&m_titleImg[1],LOGO2_IMG);
     imgloader.LoadImage(&m_mode[0],SINGLE_IMG);
@@ -96,6 +115,8 @@ CGameWidget::CGameWidget(QWidget *parent, const char *name, WFlags f) :
     //
     m_selecter = new CSelecter(m_enemy);
 
+    bdipLogo = true;//show bootlogo
+
     connect(m_timer, SIGNAL(timeout()), this, SLOT(timerTick()));
     m_timer->start(100);
 
@@ -108,6 +129,7 @@ CGameWidget::~CGameWidget()
   delete m_yesbtn;
   delete m_nobtn;
   delete m_selecter;
+  delete m_pAchieve;
 
 }
 
@@ -212,8 +234,7 @@ void CGameWidget::drawTitle(QPainter *paint)
 
   QColor black(0,0,0);
   paint->setPen(black);
-  paint->drawText(COPYLIGT_POSX, COPYLIGT_POSY, 
-                  "(C)2000-2003 TAIGA YONEKURA ALL RIGHTS RESERVED" );
+  paint->drawText( COPYLIGT_POSX, COPYLIGT_POSY,COPYLIGHT_STR );
 
 }
 void CGameWidget::drawAllBlock(QPainter *paint)
@@ -252,6 +273,15 @@ void CGameWidget::paint(void)
   QPainter painter_pixmap(m_pixmap);
   QPainter painter_widget(this);
 
+  if(bdipLogo){
+    bdipLogo = false;
+    DrawBootLogo(&painter_pixmap, width(), height() );
+    painter_pixmap.flush();
+    painter_widget.drawPixmap(0, 0, *m_pixmap);
+    sleep(2);
+    return;
+  }
+
   // get current status
   sts = STS_getStatus();
 
@@ -402,10 +432,41 @@ void CGameWidget::clickMatrix(int x,int y)
     break;
 
   case P1_WIN:
+    if( m_selectedEnemy == m_enemy[0] ){
+      // taiga
+      m_pAchieve->Win(2);
+    } else if( m_selectedEnemy == m_enemy[1] ){
+      // pen
+      m_pAchieve->Win(1);
+    } else if( m_selectedEnemy == m_enemy[2] ){
+      // taku
+      m_pAchieve->Win(0);
+    }
+
+    m_selectedEnemy->win();
+    m_pAchieve->SaveReslut();
+    STS_setSubStatus(RETRY);
+    break;
+
+  case P2_WIN:
+    if( m_selectedEnemy == m_enemy[0] ){
+      // taiga
+      m_pAchieve->Lost(2);
+    } else if( m_selectedEnemy == m_enemy[1] ){
+      // pen
+      m_pAchieve->Lost(1);
+    } else if( m_selectedEnemy == m_enemy[2] ){
+      // taku
+      m_pAchieve->Lost(0);
+    }
+    m_selectedEnemy->lost();
+    m_pAchieve->SaveReslut();
+    STS_setSubStatus(RETRY);
+    break;
+
   case VS_P1_WIN:
   case VS_P2_WIN:
   case TIME_OVER:
-  case P2_WIN:
   case DRAWGAME:
     STS_setSubStatus(RETRY);
     break;
@@ -435,6 +496,7 @@ void  CGameWidget::initEnemy(CImageLoader *pimgLoader)
 {
   QPixmap *pix[CENEMY_IMGCNT];
   int i;
+  unsigned int win,lost;
 
   // taku
   for(i = 0; i < CENEMY_IMGCNT;i++ ){
@@ -445,10 +507,11 @@ void  CGameWidget::initEnemy(CImageLoader *pimgLoader)
   pimgLoader->LoadImage(pix[1],TAKU02_IMG);
   pimgLoader->LoadImage(pix[2],TAKU04_IMG);
 
-  m_enemy[1] = new CEnemy(3);
-  m_enemy[1]->setImages(pix);
+  m_enemy[2] = new CEnemy(2);
+  m_enemy[2]->setImages(pix);
+  m_pAchieve->Get( 0, &win, &lost);
+  m_enemy[2]->setResult( win, lost);
 
-#if 0
   // pen
   for(i = 0; i < CENEMY_IMGCNT;i++ ){
     pix[i] = new QPixmap();
@@ -458,9 +521,10 @@ void  CGameWidget::initEnemy(CImageLoader *pimgLoader)
   pimgLoader->LoadImage(pix[1],PEN02_IMG);
   pimgLoader->LoadImage(pix[2],PEN04_IMG);
 
-  m_enemy[1] = new CEnemy(4);
+  m_enemy[1] = new CEnemy(3);
   m_enemy[1]->setImages(pix);
-#endif
+  m_pAchieve->Get( 1, &win, &lost);
+  m_enemy[1]->setResult( win, lost);
 
   // taiga
   for(i = 0; i < CENEMY_IMGCNT;i++ ){
@@ -473,5 +537,21 @@ void  CGameWidget::initEnemy(CImageLoader *pimgLoader)
 
   m_enemy[0] = new CEnemy(4);
   m_enemy[0]->setImages(pix);
+  m_pAchieve->Get( 2, &win, &lost);
+  m_enemy[0]->setResult( win, lost);
+}
+//
+// Draw Boot Logo
+//
+void CGameWidget::DrawBootLogo( QPainter *paint, int width, int height )
+{
 
+ QColor white( 255, 255, 255 );
+ QColor black(0,0,0);
+
+ paint->fillRect( 0, 0, width, height, white );
+ paint->drawPixmap( BOOT_LOGO_X, BOOT_LOGO_Y, m_bootlogoImg );
+
+ paint->setPen( black );
+ paint->drawText( BOOT_LOGOSTRING_X, BOOT_LOGOSTRING_Y, BOOT_LOGOSTRING );
 }
