@@ -12,6 +12,9 @@ void CImageLoader::LoadImage(QPixmap *img,int type)
 {
 
   switch(type){
+  case BOOTLOGO_IMG:
+    img->loadFromData(BOOTLOGO_IMG_DATA, sizeof (BOOTLOGO_IMG_DATA));
+    break;
   case TITLE_IMG:
     img->loadFromData(TITLEIMAGE_DATA, sizeof (TITLEIMAGE_DATA));
     break;
@@ -72,7 +75,6 @@ void CImageLoader::LoadImage(QPixmap *img,int type)
     img->loadFromData(TAIGA04IMAGE_DATA, sizeof (TAIGA04IMAGE_DATA));
     break;
 
-#if 0
   case PEN01_IMG:
     img->loadFromData(PEN01IMAGE_DATA, sizeof (PEN01IMAGE_DATA));
     break;
@@ -82,7 +84,6 @@ void CImageLoader::LoadImage(QPixmap *img,int type)
   case PEN04_IMG:
     img->loadFromData(PEN04IMAGE_DATA, sizeof (PEN04IMAGE_DATA));
     break;
-#endif
 
   case TAKU01_IMG:
     img->loadFromData(TAKU01IMAGE_DATA, sizeof (TAKU01IMAGE_DATA));
