@@ -29,7 +29,7 @@ CSelecter::CSelecter(CEnemy *enemy[])
 {
   int i;
   
-  for(i = 0;i < 2;i++){
+  for(i = 0; i < ENEMY_COUNT; i++){
     m_enemy[i] = enemy[i];
   }
 
@@ -37,7 +37,8 @@ CSelecter::CSelecter(CEnemy *enemy[])
 			      ENEMY_IMG_POSX, ENEMY1_IMG_POSY);
   m_enemyBtn[1] = new CButton(m_enemy[1]->getNormalImage(), 
 			      ENEMY_IMG_POSX,ENEMY2_IMG_POSY );
-//  m_enemyBtn[2] = new CButton(m_enemy[2]->getNormalImage(), 110, 320);
+  m_enemyBtn[2] = new CButton(m_enemy[2]->getNormalImage(), 
+			      ENEMY_IMG_POSX,ENEMY3_IMG_POSY);
 
   m_msgimg.loadFromData(SELECTMESSAGE_DATA, sizeof(SELECTMESSAGE_DATA));
   m_starimg.loadFromData(STARIMAGE_DATA, sizeof(STARIMAGE_DATA));
@@ -51,7 +52,11 @@ void CSelecter::drawSelecter(QPainter *paint)
 
   int i;
   QColor back(255,206,253);
+  QColor StrColor(0,0,0);
+  QString StrResult;
 
+  unsigned int win,lost;
+ 
   paint->fillRect(0, 0, SCREENW, SCREENH,  back);
 
   for(i = 0; i < ENEMY_COUNT; i++){
@@ -61,7 +66,20 @@ void CSelecter::drawSelecter(QPainter *paint)
 		       m_levelimg);
      drawStar(m_enemyBtn[i]->getPosX() + LEVEL_OFFSETX + STARIMG_OFFSETX,
 	      m_enemyBtn[i]->getPosY() + STARIMG_OFFSETY,
-	      2-i,paint);
+	      ENEMY_COUNT - i, paint);
+
+     m_enemy[i]->getResult( &win, &lost);
+     paint->setPen( StrColor );
+
+     StrResult = "Win:" + QString::number(win);
+     paint->drawText( m_enemyBtn[i]->getPosX() + LEVEL_OFFSETX,
+		      m_enemyBtn[i]->getPosY() + RESULT_WIN_OFFSETY, 
+		      StrResult );
+     StrResult = "Lost:" + QString::number(lost);
+     paint->drawText( m_enemyBtn[i]->getPosX() + LEVEL_OFFSETX,
+		      m_enemyBtn[i]->getPosY() + RESULT_LOST_OFFSETY, 
+		      StrResult );
+     
   }
 
   paint->drawPixmap(MESGIMG_POSX, MESGIMG_POSY, m_msgimg);
